@@ -365,16 +365,14 @@ class Track:
 
     def __ne__(self, other):
         x = self.__eq__(other)
-        if x is not NotImplemented:
-            return not x
-        return NotImplemented
+        return not x if x is not NotImplemented else NotImplemented
 
     def __hash__(self):
         return hash((self.unique_identifier,))
 
     async def get_track_display_name(
         self, max_length: int = None, author: bool = True, unformatted: bool = False, with_url: bool = False
-    ) -> str:
+    ) -> str:  # sourcery skip: low-code-quality
         if self.is_partial:
             base = await (await self.query()).query_to_queue(max_length, partial=True)
             base = SQUARE_BRACKETS.sub("", base).strip()
